@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-links" "20251007.1800"
-  "Better manage line numbers in your org-mode links."
+(define-package "org-links" "20260101.609"
+  "Better manage line numbers in links of Org mode."
   '((emacs "27.1"))
   :url "https://github.com/Anoncheg1/emacs-org-links"
-  :commit "77c13e3dc936c164a46ff4c479b22a2ec12403b6"
-  :revdesc "77c13e3dc936"
+  :commit "767fc34ae90f5af64d9fb5cb42129cdf8755ff26"
+  :revdesc "767fc34ae90f"
   :keywords '("org" "text" "hypermedia" "url")
   :authors '((nil . "github.com/Anoncheg1,codeberg.org/Anoncheg"))
   :maintainers '((nil . "github.com/Anoncheg1,codeberg.org/Anoncheg")))
